@@ -1,21 +1,23 @@
-use crate::request::Error;
-use crate::PCloudApi;
+use super::FileIdentifier;
+use crate::error::Error;
+use crate::http::HttpClient;
 use std::io::Write;
 
-impl PCloudApi {
+impl HttpClient {
     /// Download a file
     ///
     /// # Arguments
     ///
-    /// * `file_id` - ID of the file to download.
+    /// * `identifier` - ID or path to the file to download.
     /// * `write` - Where to write the file.
     ///
-    pub async fn download_file<W: Write>(
+    #[tracing::instrument(skip(self, write))]
+    pub async fn download_file<I: Into<FileIdentifier> + std::fmt::Debug, W: Write>(
         &self,
-        file_id: usize,
+        identifier: I,
         mut write: W,
     ) -> Result<usize, Error> {
-        let link = self.get_link_file(file_id).await?;
+        let link = self.get_link_file(identifier).await?;
         let mut req = self.client.get(&link).send().await?;
         let mut size = 0;
         while let Some(chunk) = req.chunk().await? {
